# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: ViewAsPlainText.pm,v 1.1 2001/06/27 05:51:52 nagler Exp $
package Bivio::Biz::Action::ViewAsPlainText;
use strict;
$Bivio::Biz::Action::ViewAsPlainText::VERSION = sprintf('%d.%02d', q$Revision: 1.1 $ =~ /\d+/g);
$_ = $Bivio::Biz::Action::ViewAsPlainText::VERSION;

=head1 NAME

Bivio::Biz::Action::ViewAsPlainText - renders view source as plain text

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::Biz::Action::ViewAsPlainText;

=cut

=head1 EXTENDS

L<Bivio::Biz::Action>

=cut

use Bivio::Biz::Action;
@Bivio::Biz::Action::ViewAsPlainText::ISA = ('Bivio::Biz::Action');

=head1 DESCRIPTION

C<Bivio::Biz::Action::ViewAsPlainText> renders a view's source as plain
text.

=cut

#=IMPORTS
use Bivio::UI::View;

#=VARIABLES
my($_PACKAGE) = __PACKAGE__;

=head1 METHODS

=cut

=for html <a name="execute"></a>

=head2 static execute(Bivio::Agent::Request req) : boolean

Renders a view's source as plain text.  I<Request.uri> must be
the name of the view.
L<Bivio::UI::View::SUFFIX|Bivio::UI::View/"SUFFIX">
will be appended.

Always returns false.

=cut

sub execute {
    my($proto, $req) = @_;
    return $proto->get_instance('LocalFilePlain')->execute(
	    $req,
	    $req->get('uri').Bivio::UI::View->SUFFIX, 'text/plain');
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: ViewAsPlainText.pm,v 1.1 2001/06/27 05:51:52 nagler Exp $

=cut

1;
