# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: UserRedirect.pm,v 1.2 2001/06/25 14:43:30 nagler Exp $
package Bivio::PetStore::Action::UserRedirect;
use strict;
$Bivio::PetStore::Action::UserRedirect::VERSION = sprintf('%d.%02d', q$Revision: 1.2 $ =~ /\d+/g);
$_ = $Bivio::PetStore::Action::UserRedirect::VERSION;

=head1 NAME

Bivio::PetStore::Action::UserRedirect - redirects to the user's realm

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::PetStore::Action::UserRedirect;

=cut

=head1 EXTENDS

L<Bivio::Biz::Action>

=cut

use Bivio::Biz::Action;
@Bivio::PetStore::Action::UserRedirect::ISA = ('Bivio::Biz::Action');

=head1 DESCRIPTION

C<Bivio::PetStore::Action::UserRedirect>

=cut

#=IMPORTS
use Bivio::IO::Trace;
use Bivio::Auth::RealmType;
use Bivio::UI::Task;

#=VARIABLES
use vars ('$_TRACE');
Bivio::IO::Trace->register;
my($_PACKAGE) = __PACKAGE__;

=head1 METHODS

=cut

=for html <a name="execute"></a>

=head2 static execute(Bivio::Agent::Request req)

Redirects user to My Site.
Takes into account path_info and redirects to the task identified
by the path_info within user area.  If no path_info, redirects to "next".

=cut

sub execute {
    my(undef, $req) = @_;
    _redirect($req, $req->get('auth_user')->get('name'),
	    Bivio::Auth::RealmType::USER());
    # DOES NOT RETURN
}

#=PRIVATE METHODS

# _redirect(Bivio::Agent::Request req, string realm, Bivio::Auth::RealmType type)
#
# Redirects to the task of interest.
#
sub _redirect {
    my($req, $realm, $type) = @_;
    my($uri) = $req->unsafe_get('path_info') || '';
    my($task);
    if (length($uri)) {
	$task = Bivio::UI::Task->unsafe_get_from_uri($uri, $type, $req);
	$req->throw_die('NOT_FOUND',
		{entity => $uri, message => 'no task for URI'})
		unless $task;
    }
    else {
	$task = $req->get('task')->get('next');
    }
    _trace($uri, '->', $task) if $_TRACE;

    # Redirect without context
    $req->client_redirect($task, $realm, $req->unsafe_get('query'), undef, 1);
    # DOES NOT RETURN
}

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: UserRedirect.pm,v 1.2 2001/06/25 14:43:30 nagler Exp $

=cut

1;
