# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: TaskId.pm,v 1.3 2001/06/25 21:10:35 moeller Exp $
package Bivio::PetStore::Agent::TaskId;
use strict;
$Bivio::PetStore::Agent::TaskId::VERSION = sprintf('%d.%02d', q$Revision: 1.3 $ =~ /\d+/g);
$_ = $Bivio::PetStore::Agent::TaskId::VERSION;

=head1 NAME

Bivio::PetStore::Agent::TaskId - demo tasks

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::PetStore::Agent::TaskId;

=cut

use Bivio::Delegate::SimpleTaskId;
@Bivio::PetStore::Agent::TaskId::ISA = ('Bivio::Delegate::SimpleTaskId');

=head1 DESCRIPTION

C<Bivio::PetStore::Agent::TaskId>

=cut

#=IMPORTS

#=VARIABLES
my($_PACKAGE) = __PACKAGE__;

=head1 METHODS

=cut

=for html <a name="get_delegate_info"></a>

=head2 static get_delegate_info() : array_ref

Returns the task declarations.

=cut

sub get_delegate_info {
    my($proto) = @_;
    return $proto->merge_task_info($proto->SUPER::get_delegate_info, [
    [qw(
        MY_SITE
        4
        GENERAL
        ANY_USER
        Action.UserRedirect
        next=USER_ACCOUNT_EDIT
    )],
    [qw(
        PRODUCTS
        500
        GENERAL
        DOCUMENT_READ
        Model.ProductList->execute_load_all_with_query
	View.products
    )],
    [qw(
        PRODUCT_SEARCH
        501
        GENERAL
        DOCUMENT_READ
        Model.ProductSearchList->execute_load_all_with_query
	View.search
    )],
    [qw(
        ITEMS
        502
        GENERAL
        DOCUMENT_READ
        Model.ItemList->execute_load_all_with_query
        Model.ItemListForm
	View.items
        next=CART
        MISSING_COOKIES=MISSING_COOKIES
    )],
    [qw(
        ITEM_DETAIL
        503
        GENERAL
        DOCUMENT_READ
        Model.Item->execute_load_parent
        Model.Inventory->execute_load_parent
        Model.ItemForm
	View.item
        next=CART
        MISSING_COOKIES=MISSING_COOKIES
    )],
    [qw(
        CART
        504
        GENERAL
        DOCUMENT_READ
        Model.CartItemList->execute_load_all
        Model.CartItemListForm
	View.cart
        next=CART
        want_query=0
    )],
    [qw(
        CHECKOUT
        505
        GENERAL
        DOCUMENT_READ
        Model.CartItemList->execute_load_all
	View.checkout
    )],
    [qw(
        PLACE_ORDER
        506
        USER
        LOGIN
        Model.OrderForm
	View.place-order
        next=ORDER_COMMIT
    )],
    [qw(
        SHIPPING_ADDRESS
        507
        USER
        LOGIN
        Model.ShippingAddressForm
	View.shipping-address
	next=PLACE_ORDER
    )],
    [qw(
        ORDER_CONFIRMATION
        508
        USER
        LOGIN
        Model.OrderConfirmationForm
	View.order-confirmation
        next=ORDER_DETAILS
    )],
    [qw(
        ORDER_DETAILS
        509
        USER
        LOGIN
	Action.LocalFilePlain
    )],
    [qw(
        MAIN
        510
        GENERAL
        DOCUMENT_READ
	View.main
    )],
    [qw(
        USER_ACCOUNT_CREATE
        511
        GENERAL
        LOGIN
	Action.Logout
        Model.UserAccountForm
	View.account
	next=USER_ACCOUNT_CREATED
        MISSING_COOKIES=MISSING_COOKIES
    )],
    [qw(
        USER_ACCOUNT_EDIT
        512
        USER
        ADMIN_READ
        Model.UserAccountForm
	View.account
	next=USER_ACCOUNT_UPDATED
    )],
    [qw(
        USER_ACCOUNT_CREATED
        513
        USER
        ADMIN_READ
	View.account-created
    )],
    [qw(
        USER_ACCOUNT_UPDATED
        514
        USER
        ADMIN_READ
	View.account-updated
    )],
    [qw(
        ORDER_COMMIT
        515
        USER
        LOGIN
        Model.Order->execute_load_parent
        Model.OrderStatus->execute_load_parent
        Model.CartItemList->execute_load_for_order
	View.order-commit
    )],
    [qw(
        MISSING_COOKIES
        516
        GENERAL
        DOCUMENT_READ
        View.missing-cookies
    )],
    [qw(
	LOGIN
	517
        GENERAL
        LOGIN
	Action.Logout
	Model.LoginForm
	View.login
        next=CART
        MISSING_COOKIES=MISSING_COOKIES
    )],
    [qw(
	LOGOUT
	518
        GENERAL
        DOCUMENT_READ
	Action.Logout->execute_clear_cart_and_logout
        Action.ClientRedirect->execute_next
        next=MAIN
    )],
    ]);
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: TaskId.pm,v 1.3 2001/06/25 21:10:35 moeller Exp $

=cut

1;
