# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: Item.pm,v 1.5 2001/06/25 14:43:30 nagler Exp $
package Bivio::PetStore::Model::Item;
use strict;
$Bivio::PetStore::Model::Item::VERSION = sprintf('%d.%02d', q$Revision: 1.5 $ =~ /\d+/g);
$_ = $Bivio::PetStore::Model::Item::VERSION;

=head1 NAME

Bivio::PetStore::Model::Item - item for sale

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::PetStore::Model::Item;

=cut

=head1 EXTENDS

L<Bivio::Biz::PropertyModel>

=cut

use Bivio::Biz::PropertyModel;
@Bivio::PetStore::Model::Item::ISA = ('Bivio::Biz::PropertyModel');

=head1 DESCRIPTION

C<Bivio::PetStore::Model::Item>

=cut

#=IMPORTS

#=VARIABLES
my($_PACKAGE) = __PACKAGE__;

=head1 METHODS

=cut

=for html <a name="format_name"></a>

=head2 format_name() : string

=head2 static format_name(string attr1, string product_name) : string

Returns the "attr1 Product.name" combination.

=cut

sub format_name {
    my($self, $attr1, $product_name) = @_;
    return $attr1.' '.$product_name if defined($attr1);

    Bivio::Die->die("expected item instance") unless ref($self);

    # call method again with arguments from instance
    return $self->format_name($self->get('attr1'),
	    $self->get_model('Product')->get('name'));
}

=for html <a name="internal_initialize"></a>

=head2 internal_initialize() : hash_ref

B<FOR INTERNAL USE ONLY>

    item_id VARCHAR(30) not null,
    product_id VARCHAR(30) not null,
    list_price NUMBER(10,2),
    unit_cost NUMBER(10,2),
    supplier_id NUMBER(18),
    status NUMBER(2) not null,
    attr1 VARCHAR(100) not null,
    attr2 VARCHAR(100),
    attr3 VARCHAR(100),
    attr4 VARCHAR(100),
    attr5 VARCHAR(100),
    constraint pk_item primary key (item_id),
    constraint fk_item_1 foreign key (product_id)
        references product_t (product_id),
    constraint fk_item_2 foreign key (supplier_id)
        references supplier_t (supplier_id)

=cut

sub internal_initialize {
    return {
	version => 1,
	table_name => 'item_t',
	columns => {
	    item_id => ['Name', 'PRIMARY_KEY'],
	    product_id => ['Product.product_id', 'NOT_NULL'],
	    list_price => ['Price', 'NONE'],
	    unit_cost => ['Price', 'NONE'],
	    supplier_id => ['Supplier.supplier_id', 'NONE'],
	    status => ['ItemStatus', 'NONE'],
	    attr1 => ['Line', 'NOT_NULL'],
	    attr2 => ['Line', 'NONE'],
	    attr3 => ['Line', 'NONE'],
	    attr4 => ['Line', 'NONE'],
	    attr5 => ['Line', 'NONE'],
	},
#TODO: this should be automatic, driven by the related field above
	other => [['product_id', 'Product.product_id']],
    };
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: Item.pm,v 1.5 2001/06/25 14:43:30 nagler Exp $

=cut

1;
