# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: ItemList.pm,v 1.4 2001/06/25 14:43:30 nagler Exp $
package Bivio::PetStore::Model::ItemList;
use strict;
$Bivio::PetStore::Model::ItemList::VERSION = sprintf('%d.%02d', q$Revision: 1.4 $ =~ /\d+/g);
$_ = $Bivio::PetStore::Model::ItemList::VERSION;

=head1 NAME

Bivio::PetStore::Model::ItemList - list of items by product

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::PetStore::Model::ItemList;

=cut

=head1 EXTENDS

L<Bivio::Biz::ListModel>

=cut

use Bivio::Biz::ListModel;
@Bivio::PetStore::Model::ItemList::ISA = ('Bivio::Biz::ListModel');

=head1 DESCRIPTION

C<Bivio::PetStore::Model::ItemList>

=cut

#=IMPORTS

#=VARIABLES
my($_PACKAGE) = __PACKAGE__;

=head1 METHODS

=cut

=for html <a name="internal_initialize"></a>

=head2 internal_initialize() : hash_ref;

B<FOR INTERNAL USE ONLY>

=cut

sub internal_initialize {
    return {
	version => 1,
	primary_key => [
	    ['Item.item_id'],
	],
	other => [
            'Product.name',
            'Item.attr1',
            'Item.list_price',
	    {
		name => 'item_name',
		type => 'Line',
		constraint => 'NONE',
	    },
	    [qw(Item.product_id Product.product_id)],
	],
	order_by => ['Item.item_id'],
	parent_id => ['Item.product_id'],
    };
}

=for html <a name="internal_post_load_row"></a>

=head2 internal_post_load_row(hash_ref row)

Sets the item_name using Item.attr1 and Product.name.

=cut

sub internal_post_load_row {
    my($self, $row) = @_;
    $row->{'item_name'} = Bivio::PetStore::Model::Item->format_name(
	    $row->{'Item.attr1'}, $row->{'Product.name'});
    return;
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: ItemList.pm,v 1.4 2001/06/25 14:43:30 nagler Exp $

=cut

1;
