# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: ItemListForm.pm,v 1.4 2001/06/25 14:43:30 nagler Exp $
package Bivio::PetStore::Model::ItemListForm;
use strict;
$Bivio::PetStore::Model::ItemListForm::VERSION = sprintf('%d.%02d', q$Revision: 1.4 $ =~ /\d+/g);
$_ = $Bivio::PetStore::Model::ItemListForm::VERSION;

=head1 NAME

Bivio::PetStore::Model::ItemListForm - add a list item to the cart

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::PetStore::Model::ItemListForm;

=cut

=head1 EXTENDS

L<Bivio::Biz::ListFormModel>

=cut

use Bivio::Biz::ListFormModel;
@Bivio::PetStore::Model::ItemListForm::ISA = ('Bivio::Biz::ListFormModel');

=head1 DESCRIPTION

C<Bivio::PetStore::Model::ItemListForm>

=cut

#=IMPORTS
use Bivio::PetStore::Model::ItemForm;

#=VARIABLES
my($_PACKAGE) = __PACKAGE__;

=head1 METHODS

=cut

=for html <a name="execute_ok_row"></a>

=head2 execute_ok_row()

Adds the current row to the cart if the add_to_cart button was selected.

=cut

sub execute_ok_row {
    my($self) = @_;
    if ($self->get('add_to_cart')) {
	Bivio::PetStore::Model::ItemForm->add_item_to_cart(
		$self->get_list_model->get_model('Item'));
    }
    return;
}

=for html <a name="internal_initialize"></a>

=head2 internal_initialize() : hash_ref;

B<FOR INTERNAL USE ONLY>

=cut

sub internal_initialize {
    my($self) = @_;
    my($info) = {
	version => 1,
	list_class => 'ItemList',
	visible => [
	    {
		name => 'add_to_cart',
		constraint => 'NONE',
		type => 'OKButton',
		in_list => 1,
	    },
	],
    };
    return $self->merge_initialize_info(
	    $self->SUPER::internal_initialize, $info);
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: ItemListForm.pm,v 1.4 2001/06/25 14:43:30 nagler Exp $

=cut

1;
