# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: Order.pm,v 1.4 2001/06/25 14:43:30 nagler Exp $
package Bivio::PetStore::Model::Order;
use strict;
$Bivio::PetStore::Model::Order::VERSION = sprintf('%d.%02d', q$Revision: 1.4 $ =~ /\d+/g);
$_ = $Bivio::PetStore::Model::Order::VERSION;

=head1 NAME

Bivio::PetStore::Model::Order - user account order

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::PetStore::Model::Order;

=cut

=head1 EXTENDS

L<Bivio::Biz::PropertyModel>

=cut

use Bivio::Biz::PropertyModel;
@Bivio::PetStore::Model::Order::ISA = ('Bivio::Biz::PropertyModel');

=head1 DESCRIPTION

C<Bivio::PetStore::Model::Order>

=cut

#=IMPORTS

#=VARIABLES
my($_PACKAGE) = __PACKAGE__;

=head1 METHODS

=cut

=for html <a name="get_status"></a>

=head2 get_status() : Bivio::PetStore::Type::OrderStatus

Returns the current status for the order.

sub get_status {
    my($self) = @_;
    return Bivio::Biz::Model->new($self->get_request, 'OrderStatus')->load({
	order_id => $self->get('order_id'),
    })->get('status');
}

=cut

=for html <a name="internal_initialize"></a>

=head2 internal_initialize() : hash_ref

B<FOR INTERNAL USE ONLY>

    order_id NUMBER(18) not null,
    cart_id NUMBER(18) not null,
    user_id NUMBER(18) not null,
    order_date date not null,
    courier VARCHAR2(100) not null,
    total_price number(10,2) not null,
    bill_to_first_name VARCHAR2(100) not null,
    bill_to_last_name VARCHAR2(100) not null,
    ship_to_first_name VARCHAR2(100) not null,
    ship_to_last_name VARCHAR2(100) not null,
    credit_card VARCHAR2(100) not null,
    expiration_date date not null,
    card_type NUMBER(2) check (card_type between 1 and 3) not null,
    bonus_miles NUMBER(18),
    constraint pk_order primary key (order_id),
    constraint fk_order_1 foreign key (order_id)
        references entity_t (entity_id),
    constraint fk_order_2 foreign key (cart_id)
        references cart_t (cart_id),
    constraint fk_order_3 foreign key (user_id)
        references user_account_t (user_id)

=cut

sub internal_initialize {
    return {
	version => 1,
	table_name => 'order_t',
	columns => {
            order_id => ['Entity.entity_id', 'PRIMARY_KEY'],
	    cart_id => ['Cart.cart_id', 'NOT_NULL'],
	    user_id => ['UserAccount.user_id', 'NOT_NULL'],
	    order_date => ['Date', 'NOT_NULL'],
	    courier => ['Line', 'NOT_NULL'],
	    total_price => ['Price', 'NOT_NULL'],
	    bill_to_first_name => ['Line', 'NOT_NULL'],
	    bill_to_last_name => ['Line', 'NOT_NULL'],
	    ship_to_first_name => ['Line', 'NOT_NULL'],
	    ship_to_last_name => ['Line', 'NOT_NULL'],
	    credit_card => ['CreditCard', 'NOT_NULL'],
	    expiration_date => ['Date', 'NOT_NULL'],
	    card_type => ['CardType', 'NOT_NULL'],
	    bonus_miles => ['Integer', 'NONE'],
	},
	auth_id => 'user_id',
    };
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: Order.pm,v 1.4 2001/06/25 14:43:30 nagler Exp $

=cut

1;
