# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: ProductSearchList.pm,v 1.4 2001/06/25 14:43:30 nagler Exp $
package Bivio::PetStore::Model::ProductSearchList;
use strict;
$Bivio::PetStore::Model::ProductSearchList::VERSION = sprintf('%d.%02d', q$Revision: 1.4 $ =~ /\d+/g);
$_ = $Bivio::PetStore::Model::ProductSearchList::VERSION;

=head1 NAME

Bivio::PetStore::Model::ProductSearchList - search products by keywords

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::PetStore::Model::ProductSearchList;

=cut

=head1 EXTENDS

L<Bivio::Biz::ListModel>

=cut

use Bivio::Biz::ListModel;
@Bivio::PetStore::Model::ProductSearchList::ISA = ('Bivio::Biz::ListModel');

=head1 DESCRIPTION

C<Bivio::PetStore::Model::ProductSearchList>

=cut

#=IMPORTS

#=VARIABLES
my($_PACKAGE) = __PACKAGE__;

=head1 METHODS

=cut

=for html <a name="internal_initialize"></a>

=head2 internal_initialize() : hash_ref;

B<FOR INTERNAL USE ONLY>

=cut

sub internal_initialize {
    return {
	version => 1,
	primary_key => [
	    ['Product.product_id'],
	],
	other => [
	    'Product.image_name',
	    'Product.description',
	],
	order_by => [
	    'Product.name',
	    'Product.product_id'
	],
#TODO: work-around for single table with search bug, needs a where clause
	where => ['Product.name', '=', 'Product.name'],
    };
}

=for html <a name="internal_pre_load"></a>

=head2 internal_pre_load(Bivio::SQL::ListQuery query, Bivio::SQL::ListSupport support, array_ref params) : string

Uses the category search parameter to refine the query if present.

=cut

sub internal_pre_load {
    my($self, $query, $support, $params) = @_;

    my($where) = '';
    if ($query->get('search')) {
	# search for any word across name/description/category
	foreach my $word (split(' ', $query->get('search'))) {
	    $where .= ' OR ' unless $where eq '';
	    $where .= "LOWER(product_t.name ||' '|| product_t.description "
		."||' '|| product_t.category_id) LIKE ?";
	    push(@$params, "%$word%");
	}
    }
    return $where
	    ? "($where)"
	    # don't return anything unless where is specified
	    : 'product_t.name != product_t.name';
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: ProductSearchList.pm,v 1.4 2001/06/25 14:43:30 nagler Exp $

=cut

1;
