# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: CreditCardExpiration.pm,v 1.2 2001/06/25 14:43:30 nagler Exp $
package Bivio::PetStore::Widget::CreditCardExpiration;
use strict;
$Bivio::PetStore::Widget::CreditCardExpiration::VERSION = sprintf('%d.%02d', q$Revision: 1.2 $ =~ /\d+/g);
$_ = $Bivio::PetStore::Widget::CreditCardExpiration::VERSION;

=head1 NAME

Bivio::PetStore::Widget::CreditCardExpiration - credit card expiration date widget

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::PetStore::Widget::CreditCardExpiration;

=cut

=head1 EXTENDS

L<Bivio::UI::Widget>

=cut

use Bivio::UI::Widget;
@Bivio::PetStore::Widget::CreditCardExpiration::ISA = ('Bivio::UI::Widget');

=head1 DESCRIPTION

C<Bivio::PetStore::Widget::CreditCardExpiration> implements a credit card
expiration date selection widget.

=cut

#=IMPORTS
use Bivio::PetStore::Type::CreditCardMonth;
use Bivio::Type::Date;

#=VARIABLES
my($_PACKAGE) = __PACKAGE__;

=head1 METHODS

=cut

=for html <a name="initialize"></a>

=head2 initialize()

Performs any startup initialization.

=cut

sub initialize {
    my($self) = @_;
    return;
}

=for html <a name="render"></a>

=head2 render(any source, string_ref buffer)

Draws the expiration date onto the buffer.

=cut

sub render {
    my($self, $source, $buffer) = @_;
    my($date) = $source->get_widget_value($self->get('value'));
    my($month) = Bivio::PetStore::Type::CreditCardMonth->from_int(
	    Bivio::Type::Date->get_part($date, 'month'));
    $$buffer .= $month->get_short_desc
	    .'/'.Bivio::Type::Date->get_part($date, 'year');
    return;
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: CreditCardExpiration.pm,v 1.2 2001/06/25 14:43:30 nagler Exp $

=cut

1;
