# Copyright (c) 1999 bivio, LLC.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: Name.pm,v 1.4 2001/06/21 08:32:39 nagler Exp $
package Bivio::Type::Name;
use strict;
$Bivio::Type::Name::VERSION = sprintf('%d.%02d', q$Revision: 1.4 $ =~ /\d+/g);

=head1 NAME

Bivio::Type::Name - holds a simple name, login id, account number, etc.

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::Type::Name;

=cut

=head1 EXTENDS

L<Bivio::Type::String>

=cut

use Bivio::Type::String;
@Bivio::Type::Name::ISA = ('Bivio::Type::String');

=head1 DESCRIPTION

C<Bivio::Type::Name> defines a simple name, e.g. first name,
last name, account identifier, and login name.  If you want
a compound name, use L<Bivio::Type::Line|Bivio::Type::Line>.

=cut

#=IMPORTS

#=VARIABLES

=head1 METHODS

=cut

=for html <a name="from_literal"></a>

=head2 static from_literal(string value) : any

Returns C<undef> if the name is empty.
Leading and trailing blanks are trimmed.

=cut

sub from_literal {
    my(undef, $value) = @_;
    return undef unless defined($value);
    # Leave middle spaces in case a "display" name.
    $value =~ s/^\s+|\s+$//g;
    return undef unless length($value);
    return $value;
}

=for html <a name="get_width"></a>

=head2 static get_width : int

Returns 30.

=cut

sub get_width {
    return 30;
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 1999 bivio, LLC.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: Name.pm,v 1.4 2001/06/21 08:32:39 nagler Exp $

=cut

1;
