# Copyright (c) 1999 bivio, LLC.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: Phone.pm,v 1.2 2001/06/25 14:43:31 nagler Exp $
package Bivio::Type::Phone;
use strict;
$Bivio::Type::Phone::VERSION = sprintf('%d.%02d', q$Revision: 1.2 $ =~ /\d+/g);

=head1 NAME

Bivio::Type::Phone - phone number

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::Type::Phone;

=cut

=head1 EXTENDS

L<Bivio::Type::Name>

=cut

use Bivio::Type::Name;
@Bivio::Type::Phone::ISA = ('Bivio::Type::Name');

=head1 DESCRIPTION

C<Bivio::Type::Phone> simple syntax checking on phone numbers.

=cut

#=IMPORTS
use Bivio::TypeError;

#=VARIABLES

=head1 METHODS

=cut

=for html <a name="from_literal"></a>

=head2 static from_literal(string value) : array

Returns C<undef> if the name is empty or zero length.
Checks syntax and returns L<Bivio::TypeError|Bivio::TypeError>.

=cut

sub from_literal {
    my($proto, $value) = @_;
    return undef unless defined($value);
    # Leave middle spaces, because user can't have them
    $value =~ s/^\s+|\s+$//g;
    return undef unless length($value);
    return (undef, Bivio::TypeError::TOO_LONG())
	    if length($value) > $proto->get_width;
#TODO: Do we need to parse better?
    return $value;
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 1999 bivio, LLC.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: Phone.pm,v 1.2 2001/06/25 14:43:31 nagler Exp $

=cut

1;
