# Copyright (c) 1999 bivio, LLC.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: TypeValue.pm,v 1.2 2001/06/21 08:32:39 nagler Exp $
package Bivio::TypeValue;
use strict;
$Bivio::TypeValue::VERSION = sprintf('%d.%02d', q$Revision: 1.2 $ =~ /\d+/g);

=head1 NAME

Bivio::TypeValue - binds a type and a value

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::TypeValue;
    my($tv) = Bivio::TypeValue->new($type, $ref);
    $tv->get('type');
    $tv->get('value');

=cut

=head1 EXTENDS

L<Bivio::Collection::Attributes>

=cut

use Bivio::Collection::Attributes;
@Bivio::TypeValue::ISA = ('Bivio::Collection::Attributes');

=head1 DESCRIPTION

C<Bivio::TypeValue> binds a type and a value.  Convenient for parameter
passing.

=cut

#=IMPORTS
use Bivio::Type;
use Carp ();

#=VARIABLES


=head1 FACTORIES

=cut

=for html <a name="new"></a>

=head2 static new(Bivio::Type type, any_ref value) : Bivio::TypeValue

Sets the I<type> and I<value> attributes.

=cut

sub new {
    my($proto, $type, $value) = @_;
    Carp::croak("$type: not a type")
		unless UNIVERSAL::isa($type, 'Bivio::Type');
    my($self) = &Bivio::Collection::Attributes::new($proto, {
	type => $type,
	value => $value,
    });
    return $self;
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 1999 bivio, LLC.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: TypeValue.pm,v 1.2 2001/06/21 08:32:39 nagler Exp $

=cut

1;
