# Copyright (c) 2000 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: HTML.pm,v 1.33 2001/06/25 14:43:31 nagler Exp $
package Bivio::UI::HTML;
use strict;
$Bivio::UI::HTML::VERSION = sprintf('%d.%02d', q$Revision: 1.33 $ =~ /\d+/g);
$_ = $Bivio::UI::HTML::VERSION;

=head1 NAME

Bivio::UI::HTML - named html components

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::UI::HTML;

=cut

=head1 EXTENDS

L<Bivio::UI::FacadeComponent>

=cut

use Bivio::UI::FacadeComponent;
use Bivio::UI::Widget;
@Bivio::UI::HTML::ISA = ('Bivio::UI::FacadeComponent');

=head1 DESCRIPTION

C<Bivio::UI::HTML> manages the HTML widgets and bits of pieces for
the HTML part of a Facade.

=cut

#=IMPORTS
use Bivio::Die;
use Bivio::UI::Facade;
use Bivio::UI::Icon;

#=VARIABLES

=head1 METHODS

=cut

=for html <a name="get_value"></a>

=head2 get_value(string name, Bivio::Collection::Attributes facade_or_req) : any

Returns the value which may be a widget or a string.

Values MUST be found or the request terminates.

=cut

sub get_value {
    my($proto, $name, $req) = @_;

    # Lookup name
    my($v) = $proto->internal_get_value($name, $req);
    Bivio::Die->die('unable to find: ', $name) unless $v;

    return $v->{value};
}

=for html <a name="handle_register"></a>

=head2 static handle_register()

Registers with Facade.

=cut

sub handle_register {
    my($proto) = @_;
    Bivio::UI::Facade->register($proto, ['Color', 'Font', 'Text']);
    return;
}

=for html <a name="internal_initialize_value"></a>

=head2 internal_initialize_value(hash_ref value)

There are three types of values at this time: strings,
subs, and widgets.  Widgets are initialized by this module.
They do not have parents. subs are executed and either return
a string or a widget, which becomes the value.

We check to make sure that the "widget" is truly a widget.

=cut

sub internal_initialize_value {
    my($self, $value) = @_;

    my($v) = $value->{config};

    if (ref($v)) {
	# If is code, call with $self as param
	$v = &$v($self) if ref($v) eq 'CODE';

	# If result of sub is widget or config is widget, call initialize.
	$v->initialize if UNIVERSAL::isa($v, 'Bivio::UI::Widget');
    }
    $value->{value} = $v;
    return;
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 2000 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: HTML.pm,v 1.33 2001/06/25 14:43:31 nagler Exp $

=cut

1;
