# Copyright (c) 1999 bivio, LLC.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: Date.pm,v 1.5 2001/06/25 14:43:31 nagler Exp $
package Bivio::UI::HTML::Format::Date;
use strict;
$Bivio::UI::HTML::Format::Date::VERSION = sprintf('%d.%02d', q$Revision: 1.5 $ =~ /\d+/g);

=head1 NAME

Bivio::UI::HTML::Format::Date - transforms a unix time to date/time string

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use Bivio::UI::HTML::Format::Date;
    Bivio::UI::HTML::Format::Date->new();

=cut

=head1 EXTENDS

L<Bivio::UI::HTML::Format> formats a unix time into a date string.

=cut

use Bivio::UI::HTML::Format;
@Bivio::UI::HTML::Format::Date::ISA = ('Bivio::UI::HTML::Format');

=head1 DESCRIPTION

C<Bivio::UI::HTML::Format::Date>

=cut

#=IMPORTS
use Bivio::Type::DateTime;

#=VARIABLES
my($_PACKAGE) = __PACKAGE__;

=head1 METHODS

=cut

=for html <a name="get_widget_value"></a>

=head2 static get_widget_value(int time) : string

Formats a date time value as a string with a 4 digit year.

=head2 static get_widget_value(int time, int year_digits) : string

Formats a date time value as a string with the specified 2 or 4 digit year.

=cut

sub get_widget_value {
    my(undef, $time, $year_digits) = @_;
#TODO: Is this right?
    return '' unless defined($time);
    die("invalid year_digits $year_digits") if (defined($year_digits)
	    && $year_digits != 2 && $year_digits != 4);
    $year_digits ||= 4;
    my($sec, $min, $hour, $mday, $mon, $year) =
	    Bivio::Type::DateTime->to_parts($time);
    return $year_digits == 2
	    ? sprintf('%02d/%02d/%02d', $mon, $mday, $year =~ /(\d\d)$/)
	    : sprintf('%02d/%02d/%04d', $mon, $mday, $year);
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 1999 bivio, LLC.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: Date.pm,v 1.5 2001/06/25 14:43:31 nagler Exp $

=cut

1;
